Index: runtime/bin/observatory_assets_empty.cc |
diff --git a/runtime/bin/snapshot_empty.cc b/runtime/bin/observatory_assets_empty.cc |
similarity index 60% |
copy from runtime/bin/snapshot_empty.cc |
copy to runtime/bin/observatory_assets_empty.cc |
index 4fd42b3d045b44f6f3345558bddd882c77f36ed8..a72f4b753728b246e7d99b6f934afab9359a5a29 100644 |
--- a/runtime/bin/snapshot_empty.cc |
+++ b/runtime/bin/observatory_assets_empty.cc |
@@ -1,9 +1,9 @@ |
-// Copyright (c) 2011, the Dart project authors. Please see the AUTHORS file |
+// Copyright (c) 2015, the Dart project authors. Please see the AUTHORS file |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
// This file is linked into the dart executable when it does not have a |
// snapshot linked into it. |
#if defined(_WIN32) |
typedef unsigned __int8 uint8_t; |
@@ -13,12 +13,12 @@ typedef unsigned __int8 uint8_t; |
#endif |
#include <stddef.h> |
- |
namespace dart { |
namespace bin { |
-const uint8_t* vm_isolate_snapshot_buffer = NULL; |
-const uint8_t* isolate_snapshot_buffer = NULL; |
+static const char observatory_assets_archive_[] = { '\0' }; |
+unsigned int observatory_assets_archive_len = 0; |
+const char* observatory_assets_archive = observatory_assets_archive_; |
} // namespace bin |
} // namespace dart |
@@ -1,9 +1,9 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
-// This file is linked into the dart executable when it does not have a |
-// snapshot linked into it. |
+// This file is linked into the dart executable when it does not have |
+// Observatory baked in. |
#if defined(_WIN32) |
typedef unsigned __int8 uint8_t; |